==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/equipmentconfigurationdefault_001/EquipmentConfigurationDefault.java <==

package net.datastream.schemas.mp_entities.equipmentconfigurationdefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INPRODUCTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PREVENTWOCOMPLETION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CGMP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DORMANTREUSE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISVEHICLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEASSPECIFIC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AUTONUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISRENTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISCONTRACT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SDMFLAG" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UTILITYBILLLEVEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GASTRACKED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGLOCKED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONNUM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "organizationid",
    "equipmentconfigstatus",
    "type",
    "status",
    "inproduction",
    "safety",
    "preventwocompletion",
    "cgmp",
    "dormantreuse",
    "outofservice",
    "isvehicle",
    "createasspecific",
    "autonumber",
    "isrental",
    "iscontract",
    "sdmflag",
    "utilitybilllevel",
    "gastracked",
    "reliabilityrankinglocked",
    "revisionnum",
    "currencycode"
})
@XmlRootElement(name = "EquipmentConfigurationDefault")
public class EquipmentConfigurationDefault {

    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "EQUIPMENTCONFIGSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type equipmentconfigstatus;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "STATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type status;
    @XmlElement(name = "INPRODUCTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String inproduction;
    @XmlElement(name = "SAFETY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String safety;
    @XmlElement(name = "PREVENTWOCOMPLETION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String preventwocompletion;
    @XmlElement(name = "CGMP", namespace = "http://schemas.datastream.net/MP_fields")
    protected String cgmp;
    @XmlElement(name = "DORMANTREUSE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String dormantreuse;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String outofservice;
    @XmlElement(name = "ISVEHICLE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String isvehicle;
    @XmlElement(name = "CREATEASSPECIFIC", namespace = "http://schemas.datastream.net/MP_fields")
    protected String createasspecific;
    @XmlElement(name = "AUTONUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String autonumber;
    @XmlElement(name = "ISRENTAL", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String isrental;
    @XmlElement(name = "ISCONTRACT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String iscontract;
    @XmlElement(name = "SDMFLAG", namespace = "http://schemas.datastream.net/MP_fields")
    protected String sdmflag;
    @XmlElement(name = "UTILITYBILLLEVEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String utilitybilllevel;
    @XmlElement(name = "GASTRACKED", namespace = "http://schemas.datastream.net/MP_fields")
    protected String gastracked;
    @XmlElement(name = "RELIABILITYRANKINGLOCKED", namespace = "http://schemas.datastream.net/MP_fields")
    protected String reliabilityrankinglocked;
    @XmlElement(name = "REVISIONNUM", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY revisionnum;
    @XmlElement(name = "CURRENCYCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String currencycode;

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentconfigstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTCONFIGSTATUS() {
        return equipmentconfigstatus;
    }

    /**
     * Définit la valeur de la propriété equipmentconfigstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTCONFIGSTATUS(STATUS_Type value) {
        this.equipmentconfigstatus = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Obtient la valeur de la propriété status.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Définit la valeur de la propriété status.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Obtient la valeur de la propriété inproduction.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINPRODUCTION() {
        return inproduction;
    }

    /**
     * Définit la valeur de la propriété inproduction.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINPRODUCTION(String value) {
        this.inproduction = value;
    }

    /**
     * Obtient la valeur de la propriété safety.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSAFETY() {
        return safety;
    }

    /**
     * Définit la valeur de la propriété safety.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSAFETY(String value) {
        this.safety = value;
    }

    /**
     * Obtient la valeur de la propriété preventwocompletion.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPREVENTWOCOMPLETION() {
        return preventwocompletion;
    }

    /**
     * Définit la valeur de la propriété preventwocompletion.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPREVENTWOCOMPLETION(String value) {
        this.preventwocompletion = value;
    }

    /**
     * Obtient la valeur de la propriété cgmp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCGMP() {
        return cgmp;
    }

    /**
     * Définit la valeur de la propriété cgmp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCGMP(String value) {
        this.cgmp = value;
    }

    /**
     * Obtient la valeur de la propriété dormantreuse.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDORMANTREUSE() {
        return dormantreuse;
    }

    /**
     * Définit la valeur de la propriété dormantreuse.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDORMANTREUSE(String value) {
        this.dormantreuse = value;
    }

    /**
     * Obtient la valeur de la propriété outofservice.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Définit la valeur de la propriété outofservice.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Obtient la valeur de la propriété isvehicle.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISVEHICLE() {
        return isvehicle;
    }

    /**
     * Définit la valeur de la propriété isvehicle.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISVEHICLE(String value) {
        this.isvehicle = value;
    }

    /**
     * Obtient la valeur de la propriété createasspecific.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCREATEASSPECIFIC() {
        return createasspecific;
    }

    /**
     * Définit la valeur de la propriété createasspecific.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCREATEASSPECIFIC(String value) {
        this.createasspecific = value;
    }

    /**
     * Obtient la valeur de la propriété autonumber.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAUTONUMBER() {
        return autonumber;
    }

    /**
     * Définit la valeur de la propriété autonumber.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAUTONUMBER(String value) {
        this.autonumber = value;
    }

    /**
     * Obtient la valeur de la propriété isrental.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISRENTAL() {
        return isrental;
    }

    /**
     * Définit la valeur de la propriété isrental.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISRENTAL(String value) {
        this.isrental = value;
    }

    /**
     * Obtient la valeur de la propriété iscontract.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISCONTRACT() {
        return iscontract;
    }

    /**
     * Définit la valeur de la propriété iscontract.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISCONTRACT(String value) {
        this.iscontract = value;
    }

    /**
     * Obtient la valeur de la propriété sdmflag.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSDMFLAG() {
        return sdmflag;
    }

    /**
     * Définit la valeur de la propriété sdmflag.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSDMFLAG(String value) {
        this.sdmflag = value;
    }

    /**
     * Obtient la valeur de la propriété utilitybilllevel.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUTILITYBILLLEVEL() {
        return utilitybilllevel;
    }

    /**
     * Définit la valeur de la propriété utilitybilllevel.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUTILITYBILLLEVEL(String value) {
        this.utilitybilllevel = value;
    }

    /**
     * Obtient la valeur de la propriété gastracked.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGASTRACKED() {
        return gastracked;
    }

    /**
     * Définit la valeur de la propriété gastracked.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGASTRACKED(String value) {
        this.gastracked = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankinglocked.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGLOCKED() {
        return reliabilityrankinglocked;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankinglocked.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGLOCKED(String value) {
        this.reliabilityrankinglocked = value;
    }

    /**
     * Obtient la valeur de la propriété revisionnum.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREVISIONNUM() {
        return revisionnum;
    }

    /**
     * Définit la valeur de la propriété revisionnum.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREVISIONNUM(QUANTITY value) {
        this.revisionnum = value;
    }

    /**
     * Obtient la valeur de la propriété currencycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCURRENCYCODE() {
        return currencycode;
    }

    /**
     * Définit la valeur de la propriété currencycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCURRENCYCODE(String value) {
        this.currencycode = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/equipmentconfigurationdefault_001/EquipmentConfigurationDefault.java <==

package net.datastream.schemas.mp_entities.equipmentconfigurationdefault_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ORGANIZATIONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCONFIGSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INPRODUCTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PREVENTWOCOMPLETION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CGMP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DORMANTREUSE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISVEHICLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREATEASSPECIFIC" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AUTONUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISRENTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISCONTRACT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SDMFLAG" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UTILITYBILLLEVEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GASTRACKED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGLOCKED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONNUM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CURRENCYCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "organizationid",
    "equipmentconfigstatus",
    "type",
    "status",
    "inproduction",
    "safety",
    "preventwocompletion",
    "cgmp",
    "dormantreuse",
    "outofservice",
    "isvehicle",
    "createasspecific",
    "autonumber",
    "isrental",
    "iscontract",
    "sdmflag",
    "utilitybilllevel",
    "gastracked",
    "reliabilityrankinglocked",
    "revisionnum",
    "currencycode"
})
@XmlRootElement(name = "EquipmentConfigurationDefault")
public class EquipmentConfigurationDefault {

    @XmlElement(name = "ORGANIZATIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "EQUIPMENTCONFIGSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type equipmentconfigstatus;
    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "STATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type status;
    @XmlElement(name = "INPRODUCTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String inproduction;
    @XmlElement(name = "SAFETY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String safety;
    @XmlElement(name = "PREVENTWOCOMPLETION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String preventwocompletion;
    @XmlElement(name = "CGMP", namespace = "http://schemas.datastream.net/MP_fields")
    protected String cgmp;
    @XmlElement(name = "DORMANTREUSE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String dormantreuse;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String outofservice;
    @XmlElement(name = "ISVEHICLE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String isvehicle;
    @XmlElement(name = "CREATEASSPECIFIC", namespace = "http://schemas.datastream.net/MP_fields")
    protected String createasspecific;
    @XmlElement(name = "AUTONUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String autonumber;
    @XmlElement(name = "ISRENTAL", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String isrental;
    @XmlElement(name = "ISCONTRACT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String iscontract;
    @XmlElement(name = "SDMFLAG", namespace = "http://schemas.datastream.net/MP_fields")
    protected String sdmflag;
    @XmlElement(name = "UTILITYBILLLEVEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String utilitybilllevel;
    @XmlElement(name = "GASTRACKED", namespace = "http://schemas.datastream.net/MP_fields")
    protected String gastracked;
    @XmlElement(name = "RELIABILITYRANKINGLOCKED", namespace = "http://schemas.datastream.net/MP_fields")
    protected String reliabilityrankinglocked;
    @XmlElement(name = "REVISIONNUM", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY revisionnum;
    @XmlElement(name = "CURRENCYCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String currencycode;

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the equipmentconfigstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTCONFIGSTATUS() {
        return equipmentconfigstatus;
    }

    /**
     * Sets the value of the equipmentconfigstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTCONFIGSTATUS(STATUS_Type value) {
        this.equipmentconfigstatus = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the status property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Gets the value of the inproduction property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINPRODUCTION() {
        return inproduction;
    }

    /**
     * Sets the value of the inproduction property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINPRODUCTION(String value) {
        this.inproduction = value;
    }

    /**
     * Gets the value of the safety property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSAFETY() {
        return safety;
    }

    /**
     * Sets the value of the safety property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSAFETY(String value) {
        this.safety = value;
    }

    /**
     * Gets the value of the preventwocompletion property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPREVENTWOCOMPLETION() {
        return preventwocompletion;
    }

    /**
     * Sets the value of the preventwocompletion property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPREVENTWOCOMPLETION(String value) {
        this.preventwocompletion = value;
    }

    /**
     * Gets the value of the cgmp property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCGMP() {
        return cgmp;
    }

    /**
     * Sets the value of the cgmp property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCGMP(String value) {
        this.cgmp = value;
    }

    /**
     * Gets the value of the dormantreuse property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDORMANTREUSE() {
        return dormantreuse;
    }

    /**
     * Sets the value of the dormantreuse property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDORMANTREUSE(String value) {
        this.dormantreuse = value;
    }

    /**
     * Gets the value of the outofservice property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Sets the value of the outofservice property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Gets the value of the isvehicle property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISVEHICLE() {
        return isvehicle;
    }

    /**
     * Sets the value of the isvehicle property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISVEHICLE(String value) {
        this.isvehicle = value;
    }

    /**
     * Gets the value of the createasspecific property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCREATEASSPECIFIC() {
        return createasspecific;
    }

    /**
     * Sets the value of the createasspecific property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCREATEASSPECIFIC(String value) {
        this.createasspecific = value;
    }

    /**
     * Gets the value of the autonumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAUTONUMBER() {
        return autonumber;
    }

    /**
     * Sets the value of the autonumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAUTONUMBER(String value) {
        this.autonumber = value;
    }

    /**
     * Gets the value of the isrental property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISRENTAL() {
        return isrental;
    }

    /**
     * Sets the value of the isrental property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISRENTAL(String value) {
        this.isrental = value;
    }

    /**
     * Gets the value of the iscontract property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISCONTRACT() {
        return iscontract;
    }

    /**
     * Sets the value of the iscontract property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISCONTRACT(String value) {
        this.iscontract = value;
    }

    /**
     * Gets the value of the sdmflag property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSDMFLAG() {
        return sdmflag;
    }

    /**
     * Sets the value of the sdmflag property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSDMFLAG(String value) {
        this.sdmflag = value;
    }

    /**
     * Gets the value of the utilitybilllevel property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUTILITYBILLLEVEL() {
        return utilitybilllevel;
    }

    /**
     * Sets the value of the utilitybilllevel property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUTILITYBILLLEVEL(String value) {
        this.utilitybilllevel = value;
    }

    /**
     * Gets the value of the gastracked property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGASTRACKED() {
        return gastracked;
    }

    /**
     * Sets the value of the gastracked property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGASTRACKED(String value) {
        this.gastracked = value;
    }

    /**
     * Gets the value of the reliabilityrankinglocked property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGLOCKED() {
        return reliabilityrankinglocked;
    }

    /**
     * Sets the value of the reliabilityrankinglocked property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGLOCKED(String value) {
        this.reliabilityrankinglocked = value;
    }

    /**
     * Gets the value of the revisionnum property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREVISIONNUM() {
        return revisionnum;
    }

    /**
     * Sets the value of the revisionnum property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREVISIONNUM(QUANTITY value) {
        this.revisionnum = value;
    }

    /**
     * Gets the value of the currencycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCURRENCYCODE() {
        return currencycode;
    }

    /**
     * Sets the value of the currencycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCURRENCYCODE(String value) {
        this.currencycode = value;
    }

}
